# folder-stamp

Generate custom macOS folder icons with a desired image as stamp.


## Some examples

The most simply use:

```sh
folstamp apple.png output.png
```

![Use demonstration](docs/demo.jpg?raw=true "Use demonstration")

Using a green folder icon:

```sh
folstamp apple.png -rgb 84 151 93 green_folder.png output.png
```

![Use demonstration](docs/demo2.jpg?raw=true "Use demonstration")


## To set up

You can use PyPI to install this program:

```sh
pip install folstamp
```

Alternative, clone and go to this repository home directory, and then run:

```sh
python setup.py install
```

Both methods install last **Folstamp** stable version on your machine.


## To use

The command has to verify:
- The input path is always the first argument and it is mandatory.
- The output path is always the last argument and it is mandatory.

Read the man of this tool to known more about its use.

> Note about man pages: if you use `pip` method to install this program, assert that man directories of your python environment are added to your `MANPATH` to can get this program's man pages with the `man` command. Python might install man pages in default machine level directories.
